#
# spec file for package lasso
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019 Red Hat, Inc., Raleigh, North Carolina, United States of America.
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global with_wsf 0
# None of these extra bindings are working or wanted right now...
%global configure_args --disable-java --disable-perl --enable-php5=no
%global somajor 3
%global libname lib%{name}%{somajor}
%global devname lib%{name}-devel
%if %{with_wsf}
  %global configure_args %{configure_args} --enable-wsf --with-sasl2=%{_prefix}/sasl2
%endif
Name:           lasso
Version:        2.6.1
Release:        lp152.2.3.1
Summary:        Liberty Alliance Single Sign On
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://lasso.entrouvert.org/
Source:         http://dev.entrouvert.org/lasso/lasso-%{version}.tar.gz
Patch0:         fix-CVE-2021-28091.patch
# Backports from upstream (from Fedora)
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  check-devel
BuildRequires:  glib2-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  libtool-ltdl-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
# The Lasso build system requires python, especially the binding generators
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-lxml
BuildRequires:  python3-six
BuildRequires:  swig
BuildRequires:  xmlsec1-devel >= 1.2.25
BuildRequires:  xmlsec1-openssl-devel >= 1.2.25
BuildRequires:  zlib-devel
%if %{with_wsf}
BuildRequires:  cyrus-sasl-devel
%endif

%description
Lasso is a library that implements the Liberty Alliance Single Sign On
standards, including the SAML and SAML2 specifications. It allows to handle
the whole life-cycle of SAML based Federations, and provides bindings
for multiple languages.

%package -n %{libname}
Summary:        Lasso runtime libraries
Group:          System/Libraries
Requires:       xmlsec1 >= 1.2.25-4

%description -n %{libname}
This package contains the runtime libraries for lasso (Liberty Alliance Single Sign On).

%package -n %{devname}
Summary:        Lasso development headers and documentation
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package contains the header files, static libraries and development
documentation for Lasso.

%package -n python3-%{name}
Summary:        Liberty Alliance Single Sign On (lasso) Python bindings
Group:          Development/Libraries/Python
Requires:       %{libname}%{?_isa} = %{version}-%{release}
Requires:       python3

%description -n python3-%{name}
Python language bindings for the lasso (Liberty Alliance Single Sign On)
library.

%prep
%autosetup -p1

# Remove any python script shebang lines (unless they refer to python3)
sed -i -E -e '/^#![[:blank:]]*(\/usr\/bin\/env[[:blank:]]+python[^3]?\>)|(\/usr\/bin\/python[^3]?\>)/d' \
  `grep -r -l -E '^#![[:blank:]]*(%{_bindir}/python[^3]?)|(%{_bindir}/env[[:blank:]]+python[^3]?)' *`

%build
%if 0%{?suse_version} && 0%{?suse_version} < 1550
# Try to fix build on Leap 15.1...
export LC_ALL="C.UTF-8"
export LANG="C.UTF-8"
%endif

./autogen.sh

%configure %{configure_args} --with-python=python3
%make_build CFLAGS="%{optflags}"

%check
%make_build check

%install
#install -m 755 -d %{buildroot}%{_datadir}/gtk-doc/html

make install exec_prefix=%{_prefix} DESTDIR=%{buildroot}
find %{buildroot} -type f -regex ".*\(.la\|.a\)" -delete -print

# Remove bogus doc files
rm -fr %{buildroot}%{_datadir}/doc/%{name}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/liblasso.so.%{somajor}*
%{_libdir}/liblasso.so.%{somajor}.*

%files -n %{devname}
%{_libdir}/liblasso.so
%{_libdir}/pkgconfig/lasso.pc
%{_includedir}/%{name}

%files -n python3-%{name}
%{python3_sitearch}/lasso.py*
%{python3_sitearch}/_lasso.so

%changelog
* Mon Jul 12 2021 Danilo Spinella <danilo.spinella@suse.com>
- Fix CVE-2021-28091 XML signature wrapping vulnerability when parsing SAML responses
  (CVE-2021-28091, bsc#1186768)
  * fix-CVE-2021-28091.patch
* Tue Apr 28 2020 Kristyna Streitova <kstreitova@suse.com>
- Update to 2.6.1
  * Keep order of SessionIndexes
  * Clear SessionIndex when private SessionIndexes is empty
  * misc: clear warnings about class_init signature using coccinelle
  * tests: fix compilation with check>0.12
  * Sort input file lists to make build deterministic
  * Modify .gitignore for PHP 7 binding
  * Add PHP 7 binding
  * Fix tests broken by new DEBUG logs
  * Improve error logging during node parsing
  * Improve configure compatibility
  * Improve compatibility with Solaris
  * Fix reference count in lasso_server_add_provider2
  * Fix python multi-version builds on jessie and stretch
  * docs: do not use Internet to fetch DTDs, entities or documents
  * fix missing include <strings.h> for index()
  * PAOS: Do not populate "Destination" attribute
  * export symbol lasso_log
  * Do not ignore WantAuthnRequestSigned value with hint MAYBE
  * Use io.open(encoding=utf8) in extract_symbols/sections.py
  * xml: adapt schema in saml2:AuthnContext
  * Fix ECP signature not found error when only assertion is signed
  * autoconf: search python interpreters by versions
  * python: make tools compatible with Py3
  * python: run tests and tools with same interpreter as binding target
  * improve resiliency of lasso_inflate
  * fix segfault in lasso_get_saml_message
  * python: add classmethod Profile.getIssuer
  * website: add news about 2.6.0 release
  * faq: fix references to lasso.profileGetIssuer
  * python: add a classmethod for lasso.profileGetIssuer
  * tools: fix segfault in lasso_get_saml_message
  * jenkins.sh: add a make clean to prevent previous build to break new ones
  * tools: set output buffer size in lasso_inflate to 20 times the input size
  * Use python interpreter specified configure script
  * Make Python scripts compatible with both Py2 and Py3
  * fix duplicate definition of LogoutTestCase and logoutSuite
  * Downcase UTF-8 file encoding name
  * Make more Python scripts compatible with both Py2 and Py3
  * Configure should search for versioned Python interpreter.
  * Clean python cache when building python3 binding
  * Move AC_SUBST declaration for AM_CFLAGS with alike
  * Remove -Werror from --enable-debugging
  * xml: fix parsing of saml:AuthnContext
- Remove upstreamed patches:
  * use-specified-python-interpreter.patch
  * duplicate-python-LogoutTestCase.patch
  * versioned-python-configure.patch
  * build-scripts-py3-compatible.patch
  * 0005-tests-use-self-generated-certificate-to-sign-federat.patch
  * 0006-Fix-ECP-signature-not-found-error-when-only-assertio.patch
  * 0007-PAOS-Do-not-populate-Destination-attribute.patch
  * 0008-Explicitly-define-tests-cases-and-add-them-to-tests.patch
* Wed Feb 26 2020 Kristyna Streitova <kstreitova@suse.com>
- remove .la and .a files in a consistent way
* Tue Feb 25 2020 Kristyna Streitova <kstreitova@suse.com>
- remove automake-version.patch that is not needed
- run spec-cleaner
* Sun Feb  9 2020 Neal Gompa <ngompa13@gmail.com>
- Sync more patches from Fedora
  * 0007-PAOS-Do-not-populate-Destination-attribute.patch
  * 0008-Explicitly-define-tests-cases-and-add-them-to-tests.patch
* Sun Jul 21 2019 Neal Gompa <ngompa13@gmail.com>
- Simplify the packaging and drop all unused sections and subpackages
* Sun Jun 30 2019 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Fedora spec
